pub enum PhysicsSet {
Prepare,
StepSimulation,
Sync,
}Expand description
High-level system sets for the main phases of the physics engine. You can use these to schedule your own systems before or after physics is run without having to worry about implementation details.
Prepare: Responsible for initializing rigid bodies and colliders and updating several components.StepSimulation: Responsible for advancing the simulation by running the steps inPhysicsStepSet.Sync: Responsible for synchronizing physics components with other data, like keepingPositionandRotationin sync withTransform.
See also
PhysicsSchedule: Responsible for advancing the simulation inPhysicsSet::StepSimulation.PhysicsStepSet: System sets for the steps of the actual physics simulation loop, like the broad phase and the substepping loop.SubstepSchedule: Responsible for running the substepping loop inPhysicsStepSet::Substeps.SubstepSet: System sets for the steps of the substepping loop, like position integration and the constraint solver.PostProcessCollisions: Responsible for running the post-process collisions group inSubstepSet::PostProcessCollisions. Empty by default.
Variants
Prepare
Responsible for initializing rigid bodies and colliders and updating several components.
See PreparePlugin.
StepSimulation
Responsible for advancing the simulation by running the steps in PhysicsStepSet.
Systems in this set are run in the PhysicsSchedule.
Sync
Responsible for synchronizing physics components with other data, like keeping Position
and Rotation in sync with Transform.
See SyncPlugin.