pub struct PhysicsDebugRenderer<'w, 's> {
pub gizmos: Gizmos<'s>,
/* private fields */
}Expand description
A SystemParam for physics debug rendering.
Fields
gizmos: Gizmos<'s>A SystemParam for drawing lines and shapes using bevy_gizmos.
Implementations
Sourceimpl<'w, 's> PhysicsDebugRenderer<'w, 's>
impl<'w, 's> PhysicsDebugRenderer<'w, 's>
Sourcepub fn draw_line_strip(
&mut self,
points: Vec<Vec3>,
position: &Position,
rotation: &Rotation,
closed: bool,
color: Color,
)
pub fn draw_line_strip( &mut self, points: Vec<Vec3>, position: &Position, rotation: &Rotation, closed: bool, color: Color, )
Draws lines between a list of points.
Sourcepub fn draw_polyline(
&mut self,
vertices: &[Vec3],
indices: &[[u32; 2]],
position: &Position,
rotation: &Rotation,
color: Color,
)
pub fn draw_polyline( &mut self, vertices: &[Vec3], indices: &[[u32; 2]], position: &Position, rotation: &Rotation, color: Color, )
Draws a polyline based on the given vertex and index buffers.
Sourcepub fn draw_arrow(
&mut self,
a: Vec3,
b: Vec3,
head_length: f32,
head_width: f32,
color: Color,
)
pub fn draw_arrow( &mut self, a: Vec3, b: Vec3, head_length: f32, head_width: f32, color: Color, )
Draws an arrow from a to b with an arrowhead that has a length of head_length
and a width of head_width.
Sourcepub fn draw_collider(
&mut self,
collider: &Collider,
position: &Position,
rotation: &Rotation,
color: Color,
)
pub fn draw_collider( &mut self, collider: &Collider, position: &Position, rotation: &Rotation, color: Color, )
Draws a collider shape with a given position and rotation.
Sourcepub fn draw_raycast(
&mut self,
origin: Vec3,
direction: Vec3,
max_time_of_impact: f32,
hits: &[RayHitData],
ray_color: Color,
point_color: Color,
normal_color: Color,
)
pub fn draw_raycast( &mut self, origin: Vec3, direction: Vec3, max_time_of_impact: f32, hits: &[RayHitData], ray_color: Color, point_color: Color, normal_color: Color, )
Draws the results of a raycast.