pub struct EditorRegistry {
pub registry: TypeRegistryArc,
pub spawn_components: HashMap<TypeId, AddDefaultComponent>,
pub clone_components: Vec<CloneComponent>,
pub remove_components: HashMap<TypeId, RemoveComponent>,
pub silent: HashSet<TypeId>,
}Expand description
Resource, which contains all custom editor registry
Fields
registry: TypeRegistryArcspawn_components: HashMap<TypeId, AddDefaultComponent>clone_components: Vec<CloneComponent>remove_components: HashMap<TypeId, RemoveComponent>silent: HashSet<TypeId>Implementations
Sourceimpl EditorRegistry
impl EditorRegistry
Sourcepub fn register<T>(&mut self)
pub fn register<T>(&mut self)
Register new component, which will be shown in editor UI and saved in prefab
Sourcepub fn silent_register<T>(&mut self)
pub fn silent_register<T>(&mut self)
Register new component, which will be hidden in editor UI and saved in prefab
Sourcepub fn only_clone_register<T>(&mut self)
pub fn only_clone_register<T>(&mut self)
Register new component, which will be cloned with editor ui clone event
Sourcepub fn get_spawn_command(&self, id: &TypeId) -> AddDefaultComponent
pub fn get_spawn_command(&self, id: &TypeId) -> AddDefaultComponent
Get spawn function for this component type
Sourcepub fn remove_by_id(&self, cmds: &mut EntityCommands<'_, '_, '_>, id: &TypeId)
pub fn remove_by_id(&self, cmds: &mut EntityCommands<'_, '_, '_>, id: &TypeId)
Get remove function for this component type
Sourcepub fn clone_entity_flat(
&self,
cmds: &mut EntityCommands<'_, '_, '_>,
src: &EntityRef<'_>,
)
pub fn clone_entity_flat( &self, cmds: &mut EntityCommands<'_, '_, '_>, src: &EntityRef<'_>, )
Get clone function for this component type