pub struct EditorTabViewer<'a, 'w, 's> {
pub world: &'a mut World,
pub commands: &'a mut Commands<'w, 's>,
pub registry: &'a mut HashMap<EditorTabName, EditorUiReg>,
pub visible: Vec<EditorTabName>,
pub tab_commands: Vec<EditorTabCommand>,
}Fields
world: &'a mut Worldcommands: &'a mut Commands<'w, 's>registry: &'a mut HashMap<EditorTabName, EditorUiReg>visible: Vec<EditorTabName>tab_commands: Vec<EditorTabCommand>Trait Implementations
Sourceimpl<'a, 'w, 's> TabViewer for EditorTabViewer<'a, 'w, 's>
impl<'a, 'w, 's> TabViewer for EditorTabViewer<'a, 'w, 's>
Sourcetype Tab = EditorTabName
type Tab = EditorTabName
The type of tab in which you can store state to be drawn in your tabs.
Sourcefn ui(
&mut self,
ui: &mut Ui,
tab_name: &mut <EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab,
)
fn ui( &mut self, ui: &mut Ui, tab_name: &mut <EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab, )
Actual tab content.
Sourcefn title(
&mut self,
tab: &mut <EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab,
) -> WidgetText
fn title( &mut self, tab: &mut <EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab, ) -> WidgetText
The title to be displayed in the tab bar.
Sourcefn clear_background(
&self,
window: &<EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab,
) -> bool
fn clear_background( &self, window: &<EditorTabViewer<'a, 'w, 's> as TabViewer>::Tab, ) -> bool
Whether the tab body will be cleared with the color specified in
TabBarStyle::bg_fill.Sourcefn add_popup(&mut self, ui: &mut Ui, surface: SurfaceIndex, node: NodeIndex)
fn add_popup(&mut self, ui: &mut Ui, surface: SurfaceIndex, node: NodeIndex)
Content of the popup under the add button. Useful for selecting what type of tab to add. Read more
Content inside the context menu shown when the tab is right-clicked. Read more
Called after each tab button is shown, so you can add a tooltip, check for clicks, etc.
Sourcefn on_close(&mut self, _tab: &mut Self::Tab) -> bool
fn on_close(&mut self, _tab: &mut Self::Tab) -> bool
This is called when the
_tab gets closed by the user. Read moreSourcefn on_add(&mut self, _surface: SurfaceIndex, _node: NodeIndex)
fn on_add(&mut self, _surface: SurfaceIndex, _node: NodeIndex)
This is called when the add button is pressed. Read more
Sourcefn force_close(&mut self, _tab: &mut Self::Tab) -> bool
fn force_close(&mut self, _tab: &mut Self::Tab) -> bool
Sourcefn tab_style_override(
&self,
_tab: &Self::Tab,
_global_style: &TabStyle,
) -> Option<TabStyle>
fn tab_style_override( &self, _tab: &Self::Tab, _global_style: &TabStyle, ) -> Option<TabStyle>
Sets custom style for given tab.